/*
 *  gui_help.cc -- BabyTrans ( Babylon Translator front-end for GTK )
 *
 *  Copyright (C) 1999-2002  Frederic Jolliton -- <babytrans@tuxee.net>
 *  Applet changes Copyright (C) 2000 by Marcus Schiesser
 *  <marcus.schiesser@student.uni-tuebingen.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <cstdlib>

#include "config.h"
#include "gui_help.h"
#include "common.h"
#include "main.h"
#include "gui_main.h"
#include "misc.h"

#include <gtk/gtk.h>
#include <gdk/gdkkeysyms.h>

namespace {

void
cbButtonOk( GtkWidget* , gpointer data )
{
	GtkWidget*			widget = (GtkWidget*)data ;
	gtk_widget_destroy( widget ) ;
}

gboolean
cbKeyPress( GtkWidget* ,
			GdkEventKey* event ,
			gpointer data )
{
	GtkWidget*			widget = (GtkWidget*)data ;
	if ( event->keyval == GDK_Escape ) {
		gtk_widget_destroy( widget ) ;
		return TRUE ;
	}
	return FALSE ;
}

void
cbResetPtr( GtkWidget* , gpointer data )
{
	*(GtkWidget**)data = 0 ;
}

} // anonymous namespace

void
guiHelp::display( const GtkWidget* parent )
{
	static GtkWidget*	widget = 0 ;
	/* window already setup and still existing ? */
	if ( widget == 0 ) {
		widget = gtk_window_new( GTK_WINDOW_TOPLEVEL ) ;

		/* title label */
		GtkWidget*			title = gtk_label_new( PACKAGE " " VERSION ) ;

		/* help */
		char*				clist_item[ 2 ] ;
		clist_item[ 0 ] = _( "Key" ) ;
		clist_item[ 1 ] = _( "Action" ) ;
		GtkWidget*			help =
			gtk_clist_new_with_titles( 2 , clist_item ) ;
		gtk_clist_column_titles_passive( GTK_CLIST( help ) ) ;
		gtk_clist_set_column_resizeable( GTK_CLIST( help ) , 0 , FALSE ) ;
		gtk_clist_set_column_resizeable( GTK_CLIST( help ) , 1 , FALSE ) ;
		gtk_clist_set_selection_mode( GTK_CLIST( help ) ,
										GTK_SELECTION_BROWSE ) ;

		for ( size_t i = 0 ; guiMain::toolbarDescription[ i ].xpmData != 0 ; ++ i ) {
			if ( app::applet && ! guiMain::toolbarDescription[ i ].isValidForApplet ) {
				continue ;
			}
			clist_item[ 0 ] = _( guiMain::toolbarDescription[ i ].key ) ;
			clist_item[ 1 ] = _( guiMain::toolbarDescription[ i ].tips ) ;
			gtk_clist_append( GTK_CLIST( help ) ,
								clist_item ) ;
		}

		/* add 30% space to the first column */
		gint				size ;
		size = gtk_clist_optimal_column_width( GTK_CLIST( help ) , 0 ) ;
		size = int( size * 1.3 ) ;
		gtk_clist_set_column_width( GTK_CLIST( help ) , 0 , size ) ;

		/* ok button */
		GtkWidget*			ok_button = gtk_button_new_with_label( _("OK") ) ;
		gtk_container_set_border_width( GTK_CONTAINER( ok_button ) , 8 ) ;
		connect( ok_button , "clicked" , cbButtonOk , (gpointer)widget ) ;

		/* vbox */
		GtkWidget*			vbox = gtk_vbox_new( FALSE , 4 ) ;
		gtk_container_set_border_width( GTK_CONTAINER( vbox ) , 4 ) ;

		GtkWidget*			separator ;
		gtk_box_pack_start( GTK_BOX( vbox ) , title , FALSE , FALSE , 0 ) ;
		separator = gtk_hseparator_new() ;
		gtk_box_pack_start( GTK_BOX( vbox ) , separator , FALSE , FALSE , 0 ) ;
		gtk_box_pack_start( GTK_BOX( vbox ) , help , TRUE , TRUE , 0 ) ;
		separator = gtk_hseparator_new() ;
		gtk_box_pack_start( GTK_BOX( vbox ) , separator , FALSE , FALSE , 0 ) ;
		gtk_box_pack_start( GTK_BOX( vbox ) , ok_button , FALSE , FALSE , 0 ) ;

		gtk_widget_show_all( vbox ) ;

		/* main window */
		gtk_window_set_title( GTK_WINDOW( widget ) ,
								_( "Help for Babytrans" ) ) ;
		gtk_container_add( GTK_CONTAINER( widget ) , vbox ) ;
		gtk_window_set_default_size( GTK_WINDOW( widget ) ,
										300 , 200 ) ;

		connect( widget , "destroy" , cbResetPtr , &widget ) ;
		connect( widget , "key-press-event" , cbKeyPress , (gpointer)widget ) ;

		gtk_widget_grab_focus( ok_button ) ;
	}
	gtk_window_set_modal( GTK_WINDOW( widget ) , TRUE ) ;
	gtk_widget_show( widget );
	if ( parent != 0 ) {
		gtk_window_set_transient_for( GTK_WINDOW( widget ) ,
									  GTK_WINDOW( parent ) ) ;
	}
}
