/*
 *  gui_info.cc -- BabyTrans ( Babylon Translator front-end for GTK )
 *
 *  Copyright (C) 1999-2002  Frederic Jolliton -- <babytrans@tuxee.net>
 *  Applet changes Copyright (C) 2000 by Marcus Schiesser
 *  <marcus.schiesser@student.uni-tuebingen.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <string>

#include <gtk/gtk.h>

#include "gui_info.h"
#include "common.h"
#include "misc.h"

#include "Wrong.xpm"

namespace {

void
cbDestroyEvent( GtkWidget* widget , gpointer data )
{
	gtk_grab_remove( widget ) ;
	gtk_main_quit() ;
}

void
cbButtonClicked( GtkButton* , gpointer data  )
{
	GtkWidget*			widget = GTK_WIDGET( data ) ;
	gtk_widget_destroy( widget ) ;
}

} // anonymous namespace

void
guiInfo::display( const std::string& title , const std::string& msg ,
				  const std::string& button_caption )
{
	GtkWidget*			widget = gtk_window_new( GTK_WINDOW_TOPLEVEL ) ;
	gtk_widget_realize( widget ) ;

	GtkWidget*			pixmap =
		createPixmap( const_cast< const gchar** >( Wrong_xpm ) ,
					  widget->window ) ;
	GtkWidget*			text = gtk_label_new( msg.c_str() ) ;
	gtk_label_set_justify( GTK_LABEL( text ) , GTK_JUSTIFY_LEFT ) ;

	GtkWidget*			hbox = gtk_hbox_new( FALSE , 3 * guiSpace ) ;
	gtk_container_set_border_width( GTK_CONTAINER( hbox ) , 2 * guiSpace ) ;
	gtk_box_pack_start( GTK_BOX( hbox ) , pixmap , FALSE , FALSE , 0 ) ;
	gtk_box_pack_start( GTK_BOX( hbox ) , text , FALSE , FALSE , 0 ) ;

	GtkWidget*			ok_button =
		gtk_button_new_with_label( button_caption.c_str() ) ;
	gtk_container_set_border_width( GTK_CONTAINER( ok_button ) ,
									guiSpace ) ;
	connect( ok_button , "clicked" , cbButtonClicked , widget ) ;

	GtkWidget*			vbox = gtk_vbox_new( FALSE , guiSpace ) ;
	gtk_box_pack_start( GTK_BOX( vbox ) ,
						gtk_label_new( title.c_str() ) ,
						FALSE , FALSE , guiSpace ) ;
	gtk_box_pack_start( GTK_BOX( vbox ) , hbox ,
						TRUE , TRUE , 0 ) ;
	gtk_box_pack_start( GTK_BOX( vbox ) ,
						gtk_hseparator_new() ,
						FALSE , FALSE , 0 ) ;
	gtk_box_pack_start( GTK_BOX( vbox ) ,
						ok_button ,
						FALSE , FALSE , 0 ) ;

	/* main window */
	gtk_container_add( GTK_CONTAINER( widget ) , vbox ) ;
	gtk_window_set_modal( GTK_WINDOW( widget ) , TRUE ) ;
	gtk_widget_show_all( widget ) ;
	gtk_grab_add( widget ) ;
	connect( widget , "destroy" , cbDestroyEvent , widget ) ;

	gtk_widget_grab_focus( ok_button ) ;

	gtk_main() ;
}
