/*
 *  gui_prefs.cc -- BabyTrans ( Babylon Translator front-end for GTK )
 *
 *  Copyright (C) 1999-2002  Frederic Jolliton -- <babytrans@tuxee.net>
 *  Applet changes Copyright (C) 2000 by Marcus Schiesser
 *  <marcus.schiesser@student.uni-tuebingen.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <string>
#include <gtk/gtk.h>
#include <gdk/gdkkeysyms.h>

#include <gui_prefs.h>

#include "common.h"
#include "main.h"
#include "misc.h"
#include "str_format.h"

namespace {

/* The setup window widget */
GtkWidget*			widget = 0 ;

/* The autoraise button in setup dialog box */
GtkWidget*			autoRaiseWidget = 0 ;

/* The automode button in setup dialog box */
GtkWidget*			automodeWidget = 0 ;

struct {
	GtkWidget*			widget ;
	const char*			caption ;
	GtkToolbarStyle		style ;
} radioDesc[] = {
	{ 0 , N_( "Text" ) , GTK_TOOLBAR_TEXT } ,
	{ 0 , N_( "Icons" ) , GTK_TOOLBAR_ICONS } ,
	{ 0 , N_( "Text and icons" ) , GTK_TOOLBAR_BOTH } ,
	{ 0 , 0 , GtkToolbarStyle() }
} ;

std::string			dictionary ;

void
cbResetPtr( GtkWidget* , gpointer data )
{
	*(GtkWidget**)data = 0 ;
}

void
cbButtonOk( GtkWidget* , gpointer data )
{
	/* set dictionary */
	if ( ! dictionary.empty() ) {
		app::setDictionary( dictionary ) ;
	}

	/* set toolbar style */
	size_t				i ;
	for ( i = 0 ; radioDesc[ i ].caption != 0 ; ++ i ) {
		GtkToggleButton*		button =
					GTK_TOGGLE_BUTTON( radioDesc[ i ].widget ) ;
		if ( gtk_toggle_button_get_active( button ) )
			break ;
	}
	g_assert( radioDesc[ i ].caption != 0 ) ;
	guiMain::setToolbarStyle( radioDesc[ i ].style ) ;

	app::setAuto( bool( gtk_toggle_button_get_active(
			GTK_TOGGLE_BUTTON( automodeWidget ) ) ) ) ;
	app::autoRaise = bool( gtk_toggle_button_get_active(
			GTK_TOGGLE_BUTTON( autoRaiseWidget ) ) ) ;

	GtkWidget*			widget = GTK_WIDGET( data ) ;
	gtk_widget_hide( widget ) ;

	guiMain::update() ;
}

void
cbButtonCancel( GtkWidget* , gpointer data )
{
	GtkWidget*			widget = GTK_WIDGET( data ) ;
	// gtk_widget_destroy( widget ) ;
	gtk_widget_hide( widget ) ;
}

void
cbSelectLanguage( GtkWidget* widget , gint row , gint column ,
				  GdkEvent* event , gpointer data )
{
	dictionary = app::languages[ row ].shortName ;
}

void
cbButtonAuto( GtkWidget* widget , gpointer data )
{
		gtk_widget_set_sensitive(
			autoRaiseWidget ,
			gtk_toggle_button_get_active(
				GTK_TOGGLE_BUTTON( automodeWidget ) ) ) ;
}

gboolean
cbKeyPress( GtkWidget* ,
			GdkEventKey* event ,
			gpointer data )
{
	GtkWidget*			widget = GTK_WIDGET( data ) ;
	if ( event->keyval == GDK_Escape ) {
		// gtk_widget_destroy( widget ) ;
		gtk_widget_hide( widget ) ;
		return TRUE ;
	}
	return FALSE ;
}

} // anonymous namespace

void
guiSetup::display( const GtkWidget* parent )
{
	if ( widget == 0 ) {
		widget = gtk_window_new( GTK_WINDOW_TOPLEVEL ) ;

		/* dictionary page */
		GtkWidget*			list = gtk_clist_new( 1 ) ;
		GtkCList*			list_ = GTK_CLIST( list ) ;
		gtk_container_set_border_width( GTK_CONTAINER( list ) ,
										guiSpace ) ;
		gtk_clist_column_titles_show( list_ ) ;
		gtk_clist_column_titles_passive( list_ ) ;
		gtk_clist_set_column_resizeable( list_ , 0 , FALSE ) ;
		gtk_clist_set_column_title( list_ , 0 , _( "Current dictionary" ) ) ;
		gtk_clist_set_selection_mode( list_ , GTK_SELECTION_SINGLE ) ;

		char*				line[ 1 ] ;
		for ( app::LanguageList::size_type
				i = 0 ;
				i < app::languages.size() ;
				++ i ) {
			line[ 0 ] = const_cast< char* >( app::languages[ i ]
												.longName.c_str() ) ;
			gtk_clist_append( list_ , line ) ;
		}
		gtk_clist_select_row( list_ , app::getDictionary() , 0 ) ;

		connect( list , "select-row" , cbSelectLanguage , 0 ) ;

#ifndef GNOME_APPLET
		/* misc. page */
		GSList*				group = 0 ;
		for ( size_t i = 0 ; radioDesc[ i ].caption != 0 ; ++ i ) {
			const char*			caption = _( radioDesc[ i ].caption ) ;
			GtkWidget*			radioWidget =
				gtk_radio_button_new_with_label( group , caption ) ;
			radioDesc[ i ].widget = radioWidget ;
			group = gtk_radio_button_group( GTK_RADIO_BUTTON( radioWidget ) ) ;
			if ( radioDesc[ i ].style == guiMain::getToolbarStyle() ) {
				gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( radioWidget ) ,
												TRUE ) ;
			}
		}

		GtkWidget*			radioTable =
			gtk_table_new( 1 , ARRAY_SIZE( radioDesc ) - 1 , FALSE ) ;
		gtk_container_set_border_width( GTK_CONTAINER( radioTable ) ,
										guiSpace ) ;
		for ( size_t i = 0 ; radioDesc[ i ].widget != 0 ; ++ i )
			gtk_table_attach( GTK_TABLE( radioTable ) ,
								radioDesc[ i ].widget ,
								0 , 1 , i , i + 1 ,
								GTK_FILL , GTK_EXPAND , 0 , 0 ) ;

		GtkWidget*			frame = gtk_frame_new( _( "Toolbar" ) ) ;
		gtk_container_set_border_width( GTK_CONTAINER( frame ) ,
										guiSpace ) ;
		gtk_container_add( GTK_CONTAINER( frame ) , radioTable ) ;

		/* auto raise button */

		automodeWidget =
			gtk_check_button_new_with_label( _( "Auto mode active" ) ) ;
		connect( automodeWidget , "toggled" , cbButtonAuto , 0 ) ;

		autoRaiseWidget = gtk_check_button_new_with_label( _( "Auto Raise" ) ) ;

		if ( app::getAuto() ) {
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( automodeWidget ) ,
										  TRUE ) ;
		} else {
			gtk_widget_set_sensitive( autoRaiseWidget , FALSE ) ;
		}
		gtk_toggle_button_set_active(
			GTK_TOGGLE_BUTTON( autoRaiseWidget ) ,
			app::autoRaise ) ;

		GtkWidget*			ar_table =
			gtk_table_new( 1 , 1 , FALSE ) ;
		gtk_container_set_border_width( GTK_CONTAINER( ar_table ) ,
										guiSpace ) ;
		gtk_table_attach( GTK_TABLE( ar_table ) ,
							automodeWidget ,
							0 , 1 , 0 , 1 ,
							GTK_FILL , GTK_EXPAND , 0 , 0 ) ;
		gtk_table_attach( GTK_TABLE( ar_table ) ,
							autoRaiseWidget ,
							0 , 1 , 1 , 2 ,
							GTK_FILL , GTK_EXPAND , 0 , 0 ) ;

		GtkWidget*			frame2 = gtk_frame_new( _( "Auto mode" ) ) ;
		gtk_container_set_border_width( GTK_CONTAINER( frame2 ) ,
										guiSpace ) ;
		gtk_container_add( GTK_CONTAINER( frame2 ) , ar_table ) ;
		gtk_widget_show_all( frame2 ) ;

		/* misc. */

		GtkWidget*			misc_vbox = gtk_vbox_new( FALSE , 0 ) ;
		gtk_box_pack_start( GTK_BOX( misc_vbox ) , frame ,
							FALSE , FALSE , 0 ) ;
		gtk_box_pack_start( GTK_BOX( misc_vbox ) , frame2 ,
							FALSE , FALSE , 0 ) ;
#endif

		GtkWidget*			tmp ;

		/* notebook */
		GtkWidget*			notebook = gtk_notebook_new() ;
		tmp = gtk_label_new( _( "Dictionary" ) ) ;
		gtk_notebook_append_page( GTK_NOTEBOOK( notebook ) , list , tmp ) ;

#ifndef GNOME_APPLET
		tmp = gtk_label_new( _( "Misc." ) ) ;
		gtk_notebook_append_page( GTK_NOTEBOOK( notebook ) , misc_vbox , tmp ) ;
#endif
		/* OK button */
		GtkWidget*			ok_button =
			gtk_button_new_with_label( strFormat( " %1 " ).with( _( "OK" ) ) ) ;
		connect( ok_button , "clicked" , cbButtonOk , widget ) ;

		GtkWidget*			cancel_button =
			gtk_button_new_with_label( strFormat( " %1 " ).
										with( _( "Cancel" ) ) ) ;
		connect( cancel_button , "clicked" , cbButtonCancel , widget ) ;

		GtkWidget*			button_box = gtk_hbox_new( TRUE , guiSpace * 2 ) ;
		gtk_container_add( GTK_CONTAINER( button_box ) , ok_button ) ;
		gtk_container_add( GTK_CONTAINER( button_box ) , cancel_button ) ;

		GtkWidget*			box_box = gtk_hbox_new( FALSE , 0 ) ;
		gtk_box_pack_end( GTK_BOX( box_box ) , button_box ,
							FALSE , FALSE , 0 ) ;

		/* main vbox */
		GtkWidget*			main_vbox = gtk_vbox_new( FALSE , guiSpace ) ;
		gtk_container_add( GTK_CONTAINER( main_vbox ) , notebook ) ;
		gtk_box_pack_start( GTK_BOX( main_vbox ) ,
							box_box , FALSE , FALSE , 0 ) ;
		gtk_widget_show_all( main_vbox ) ;

		/* toplevel widget */
		gtk_container_add( GTK_CONTAINER( widget ) , main_vbox ) ;
		gtk_container_set_border_width( GTK_CONTAINER( widget ) , guiSpace ) ;
		connect( widget , "key-press-event" , cbKeyPress , widget ) ;
		connect( widget , "destroy" , cbResetPtr , &widget ) ;

		/* dictionary list will have the focus by default */
		gtk_widget_grab_focus( list ) ;
	}
	gtk_widget_show( widget ) ;
	gtk_window_set_modal( GTK_WINDOW( widget ) , TRUE ) ;
	if ( parent != 0 ) {
		gtk_window_set_transient_for( GTK_WINDOW( widget ) ,
									  GTK_WINDOW( parent ) ) ;
	}

	dictionary.erase() ;
}

// vim: set ts=4 sw=4:
